@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Red Hat, Inc.
+ * Copyright (c) 2012-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -87,7 +87,8 @@ public class GitlabFactoryParametersResolverTest {
   /** Check url which is not a Gitlab url can't be accepted by this resolver */
   @Test
   public void checkInvalidAcceptUrl() {
-    Map<String, String> parameters = singletonMap(URL_PARAMETER_NAME, "http://github.com");
+    Map<String, String> parameters =
+        singletonMap(URL_PARAMETER_NAME, "http://github.com/user/repo");
     // shouldn't be accepted
     assertFalse(gitlabFactoryParametersResolver.accept(parameters));
   }
