@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Red Hat, Inc.
+ * Copyright (c) 2012-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -59,6 +59,13 @@ public class DefaultFactoryParameterResolver implements FactoryParametersResolve
     this.urlFetcher = urlFetcher;
   }
 
+  /**
+   * Check if this resolver can be used with the given parameters.
+   *
+   * @param factoryParameters map of parameters dedicated to factories
+   * @return true if it will be accepted by the resolver implementation or false if it is not
+   *     accepted
+   */
   @Override
   public boolean accept(Map<String, String> factoryParameters) {
     String url = factoryParameters.get(URL_PARAMETER_NAME);
@@ -88,7 +95,9 @@ public class DefaultFactoryParameterResolver implements FactoryParametersResolve
     }
     return urlFactoryBuilder
         .createFactoryFromDevfile(
-            new DefaultFactoryUrl().withDevfileFileLocation(devfileLocation),
+            new DefaultFactoryUrl()
+                .withDevfileFileLocation(devfileLocation)
+                .withUrl(devfileLocation),
             new URLFileContentProvider(devfileURI, urlFetcher),
             extractOverrideParams(factoryParameters),
             false)
