@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Red Hat, Inc.
+ * Copyright (c) 2012-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -132,7 +132,7 @@ public class URLFactoryBuilderTest {
     FactoryMetaDto factory =
         urlFactoryBuilder
             .createFactoryFromDevfile(
-                new DefaultFactoryUrl().withDevfileFileLocation(myLocation),
+                new DefaultFactoryUrl().withDevfileFileLocation(myLocation).withUrl("url"),
                 fileContentProvider,
                 emptyMap(),
                 false)
@@ -157,7 +157,7 @@ public class URLFactoryBuilderTest {
     FactoryMetaDto factory =
         urlFactoryBuilder
             .createFactoryFromDevfile(
-                new DefaultFactoryUrl().withDevfileFileLocation(myLocation),
+                new DefaultFactoryUrl().withDevfileFileLocation(myLocation).withUrl("url"),
                 fileContentProvider,
                 emptyMap(),
                 false)
@@ -218,6 +218,11 @@ public class URLFactoryBuilderTest {
             return null;
           }
 
+          @Override
+          public Optional<String> getCredentials() {
+            return Optional.empty();
+          }
+
           @Override
           public void setDevfileFilename(String devfileName) {}
         };
@@ -285,6 +290,11 @@ public class URLFactoryBuilderTest {
             return null;
           }
 
+          @Override
+          public Optional<String> getCredentials() {
+            return Optional.empty();
+          }
+
           @Override
           public void setDevfileFilename(String devfileName) {
             this.devfileName = devfileName;
@@ -326,7 +336,7 @@ public class URLFactoryBuilderTest {
     FactoryMetaDto factory =
         localUrlFactoryBuilder
             .createFactoryFromDevfile(
-                new DefaultFactoryUrl().withDevfileFileLocation(myLocation),
+                new DefaultFactoryUrl().withDevfileFileLocation(myLocation).withUrl("url"),
                 fileContentProvider,
                 emptyMap(),
                 false)
